//
//  RecipientsMultiViewController.m
//  RecipientsViewController
//
//  Created by Igor on 25/01/2017.
//  Copyright © 2017 Igor. All rights reserved.
//

@import IGListKit;
#import "Contact.h"
#import "RecipientsCell.h"
#import "RecipientsMultiSectionController.h"
#import "RecipientsMultiViewController.h"


@interface RecipientsMultiViewController () <IGListAdapterDataSource>

@end



@implementation RecipientsMultiViewController
{
    IGListCollectionView *_collectionView;
    IGListAdapter *_adapter;
    UIView *_emptyView;
    
    RecipientsMultiSectionController *sc_;
    
    RecipientsMultiModel *_model;
}


- (void)viewDidLoad {
    [super viewDidLoad];

    UICollectionViewFlowLayout *layout = [[UICollectionViewFlowLayout alloc] init];
    layout.scrollDirection = UICollectionViewScrollDirectionHorizontal;
    _collectionView = [[IGListCollectionView alloc] initWithFrame:CGRectZero collectionViewLayout:layout];
    _collectionView.alwaysBounceVertical = NO;
    _collectionView.alwaysBounceHorizontal = YES;
    _collectionView.backgroundColor = [UIColor cyanColor];
    
    _adapter = [[IGListAdapter alloc] initWithUpdater:[IGListAdapterUpdater new] viewController:self workingRangeSize:0];
    _adapter.collectionView = _collectionView;
    _adapter.dataSource = self;
    
    _selectedContactIndex = -1;
    _model = [RecipientsMultiModel new];
    [self.view addSubview:_collectionView];
}

- (void)viewWillLayoutSubviews
{
    [super viewWillLayoutSubviews];
    _collectionView.frame = self.view.frame;
}

- (void)setContacts:(NSArray<id> *)contacts
{
    _contacts = contacts;
    [_adapter performUpdatesAnimated:YES completion:nil];
}

- (void)setSelectedContactIndex:(NSInteger)selectedContactIndex
{
    if (selectedContactIndex == _selectedContactIndex)
        return;
    
    NSMutableArray *objectsToReload = [NSMutableArray new];
    // reset previously selected one
    if (_selectedContactIndex >= 0) {
        RecipientsMultiSectionController *r = [_adapter sectionControllerForObject:_contacts[_selectedContactIndex]];
        r.model.selected = NO;
        [objectsToReload addObject:r.model.contact];
    }
    // set selection
    if (selectedContactIndex >= 0) {
        RecipientsMultiSectionController *r = [_adapter sectionControllerForObject:_contacts[selectedContactIndex]];
        r.model.selected = YES;
        [objectsToReload addObject:r.model.contact];
    }

    // update
    _selectedContactIndex = selectedContactIndex;
    [_adapter reloadObjects:objectsToReload];
}




#pragma mark - IGListAdapterDataSource

- (IGListSectionController<IGListSectionType> *)listAdapter:(IGListAdapter *)listAdapter sectionControllerForObject:(id)object
{
    
    RecipientsMultiSectionController *secCtl = [RecipientsMultiSectionController new];
    secCtl.parent = self;   // weak ref
    
    return secCtl;
}

- (NSArray<id<IGListDiffable>> *)objectsForListAdapter:(IGListAdapter *)listAdapter
{
    if (!self.contacts)
        return nil;
    return self.contacts;
}

- (UIView *)emptyViewForListAdapter:(IGListAdapter *)listAdapter
{
    if (!_emptyView) {
        _emptyView = [UIView new];
    }
    
    return _emptyView;
}

@end
